@@ -6,9 +6,9 @@ Type annotations for codebuild service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codebuild.type_defs import BatchDeleteBuildsOutputTypeDef
+    from mypy_boto3_codebuild.type_defs import BatchDeleteBuildsInputRequestTypeDef
 
-    data: BatchDeleteBuildsOutputTypeDef = {...}
+    data: BatchDeleteBuildsInputRequestTypeDef = {...}
     ```
 """
 import sys
@@ -31,12 +31,19 @@ from .literals import (
     LanguageTypeType,
     LogsConfigStatusTypeType,
     PlatformTypeType,
+    ProjectSortByTypeType,
+    ReportCodeCoverageSortByTypeType,
     ReportExportConfigTypeType,
+    ReportGroupSortByTypeType,
     ReportGroupStatusTypeType,
+    ReportGroupTrendFieldTypeType,
     ReportPackagingTypeType,
     ReportStatusTypeType,
     ReportTypeType,
+    RetryBuildBatchTypeType,
     ServerTypeType,
+    SharedResourceSortByTypeType,
+    SortOrderTypeType,
     SourceTypeType,
     StatusTypeType,
     WebhookBuildTypeType,
@@ -54,11 +61,17 @@ else:
 
 
 __all__ = (
+    "BatchDeleteBuildsInputRequestTypeDef",
     "BatchDeleteBuildsOutputTypeDef",
+    "BatchGetBuildBatchesInputRequestTypeDef",
     "BatchGetBuildBatchesOutputTypeDef",
+    "BatchGetBuildsInputRequestTypeDef",
     "BatchGetBuildsOutputTypeDef",
+    "BatchGetProjectsInputRequestTypeDef",
     "BatchGetProjectsOutputTypeDef",
+    "BatchGetReportGroupsInputRequestTypeDef",
     "BatchGetReportGroupsOutputTypeDef",
+    "BatchGetReportsInputRequestTypeDef",
     "BatchGetReportsOutputTypeDef",
     "BatchRestrictionsTypeDef",
     "BuildArtifactsTypeDef",
@@ -74,33 +87,59 @@ __all__ = (
     "CloudWatchLogsConfigTypeDef",
     "CodeCoverageReportSummaryTypeDef",
     "CodeCoverageTypeDef",
+    "CreateProjectInputRequestTypeDef",
     "CreateProjectOutputTypeDef",
+    "CreateReportGroupInputRequestTypeDef",
     "CreateReportGroupOutputTypeDef",
+    "CreateWebhookInputRequestTypeDef",
     "CreateWebhookOutputTypeDef",
     "DebugSessionTypeDef",
+    "DeleteBuildBatchInputRequestTypeDef",
     "DeleteBuildBatchOutputTypeDef",
+    "DeleteProjectInputRequestTypeDef",
+    "DeleteReportGroupInputRequestTypeDef",
+    "DeleteReportInputRequestTypeDef",
+    "DeleteResourcePolicyInputRequestTypeDef",
+    "DeleteSourceCredentialsInputRequestTypeDef",
     "DeleteSourceCredentialsOutputTypeDef",
+    "DeleteWebhookInputRequestTypeDef",
+    "DescribeCodeCoveragesInputRequestTypeDef",
     "DescribeCodeCoveragesOutputTypeDef",
+    "DescribeTestCasesInputRequestTypeDef",
     "DescribeTestCasesOutputTypeDef",
     "EnvironmentImageTypeDef",
     "EnvironmentLanguageTypeDef",
     "EnvironmentPlatformTypeDef",
     "EnvironmentVariableTypeDef",
     "ExportedEnvironmentVariableTypeDef",
+    "GetReportGroupTrendInputRequestTypeDef",
     "GetReportGroupTrendOutputTypeDef",
+    "GetResourcePolicyInputRequestTypeDef",
     "GetResourcePolicyOutputTypeDef",
     "GitSubmodulesConfigTypeDef",
+    "ImportSourceCredentialsInputRequestTypeDef",
     "ImportSourceCredentialsOutputTypeDef",
+    "InvalidateProjectCacheInputRequestTypeDef",
+    "ListBuildBatchesForProjectInputRequestTypeDef",
     "ListBuildBatchesForProjectOutputTypeDef",
+    "ListBuildBatchesInputRequestTypeDef",
     "ListBuildBatchesOutputTypeDef",
+    "ListBuildsForProjectInputRequestTypeDef",
     "ListBuildsForProjectOutputTypeDef",
+    "ListBuildsInputRequestTypeDef",
     "ListBuildsOutputTypeDef",
     "ListCuratedEnvironmentImagesOutputTypeDef",
+    "ListProjectsInputRequestTypeDef",
     "ListProjectsOutputTypeDef",
+    "ListReportGroupsInputRequestTypeDef",
     "ListReportGroupsOutputTypeDef",
+    "ListReportsForReportGroupInputRequestTypeDef",
     "ListReportsForReportGroupOutputTypeDef",
+    "ListReportsInputRequestTypeDef",
     "ListReportsOutputTypeDef",
+    "ListSharedProjectsInputRequestTypeDef",
     "ListSharedProjectsOutputTypeDef",
+    "ListSharedReportGroupsInputRequestTypeDef",
     "ListSharedReportGroupsOutputTypeDef",
     "ListSourceCredentialsOutputTypeDef",
     "LogsConfigTypeDef",
@@ -117,6 +156,7 @@ __all__ = (
     "ProjectSourceTypeDef",
     "ProjectSourceVersionTypeDef",
     "ProjectTypeDef",
+    "PutResourcePolicyInputRequestTypeDef",
     "PutResourcePolicyOutputTypeDef",
     "RegistryCredentialTypeDef",
     "ReportExportConfigTypeDef",
@@ -127,28 +167,44 @@ __all__ = (
     "ReportWithRawDataTypeDef",
     "ResolvedArtifactTypeDef",
     "ResponseMetadataTypeDef",
+    "RetryBuildBatchInputRequestTypeDef",
     "RetryBuildBatchOutputTypeDef",
+    "RetryBuildInputRequestTypeDef",
     "RetryBuildOutputTypeDef",
     "S3LogsConfigTypeDef",
     "S3ReportExportConfigTypeDef",
     "SourceAuthTypeDef",
     "SourceCredentialsInfoTypeDef",
+    "StartBuildBatchInputRequestTypeDef",
     "StartBuildBatchOutputTypeDef",
+    "StartBuildInputRequestTypeDef",
     "StartBuildOutputTypeDef",
+    "StopBuildBatchInputRequestTypeDef",
     "StopBuildBatchOutputTypeDef",
+    "StopBuildInputRequestTypeDef",
     "StopBuildOutputTypeDef",
     "TagTypeDef",
     "TestCaseFilterTypeDef",
     "TestCaseTypeDef",
     "TestReportSummaryTypeDef",
+    "UpdateProjectInputRequestTypeDef",
     "UpdateProjectOutputTypeDef",
+    "UpdateReportGroupInputRequestTypeDef",
     "UpdateReportGroupOutputTypeDef",
+    "UpdateWebhookInputRequestTypeDef",
     "UpdateWebhookOutputTypeDef",
     "VpcConfigTypeDef",
     "WebhookFilterTypeDef",
     "WebhookTypeDef",
 )
 
+BatchDeleteBuildsInputRequestTypeDef = TypedDict(
+    "BatchDeleteBuildsInputRequestTypeDef",
+    {
+        "ids": List[str],
+    },
+)
+
 BatchDeleteBuildsOutputTypeDef = TypedDict(
     "BatchDeleteBuildsOutputTypeDef",
     {
@@ -158,6 +214,13 @@ BatchDeleteBuildsOutputTypeDef = TypedDict(
     },
 )
 
+BatchGetBuildBatchesInputRequestTypeDef = TypedDict(
+    "BatchGetBuildBatchesInputRequestTypeDef",
+    {
+        "ids": List[str],
+    },
+)
+
 BatchGetBuildBatchesOutputTypeDef = TypedDict(
     "BatchGetBuildBatchesOutputTypeDef",
     {
@@ -167,6 +230,13 @@ BatchGetBuildBatchesOutputTypeDef = TypedDict(
     },
 )
 
+BatchGetBuildsInputRequestTypeDef = TypedDict(
+    "BatchGetBuildsInputRequestTypeDef",
+    {
+        "ids": List[str],
+    },
+)
+
 BatchGetBuildsOutputTypeDef = TypedDict(
     "BatchGetBuildsOutputTypeDef",
     {
@@ -176,6 +246,13 @@ BatchGetBuildsOutputTypeDef = TypedDict(
     },
 )
 
+BatchGetProjectsInputRequestTypeDef = TypedDict(
+    "BatchGetProjectsInputRequestTypeDef",
+    {
+        "names": List[str],
+    },
+)
+
 BatchGetProjectsOutputTypeDef = TypedDict(
     "BatchGetProjectsOutputTypeDef",
     {
@@ -185,6 +262,13 @@ BatchGetProjectsOutputTypeDef = TypedDict(
     },
 )
 
+BatchGetReportGroupsInputRequestTypeDef = TypedDict(
+    "BatchGetReportGroupsInputRequestTypeDef",
+    {
+        "reportGroupArns": List[str],
+    },
+)
+
 BatchGetReportGroupsOutputTypeDef = TypedDict(
     "BatchGetReportGroupsOutputTypeDef",
     {
@@ -194,6 +278,13 @@ BatchGetReportGroupsOutputTypeDef = TypedDict(
     },
 )
 
+BatchGetReportsInputRequestTypeDef = TypedDict(
+    "BatchGetReportsInputRequestTypeDef",
+    {
+        "reportArns": List[str],
+    },
+)
+
 BatchGetReportsOutputTypeDef = TypedDict(
     "BatchGetReportsOutputTypeDef",
     {
@@ -429,6 +520,46 @@ CodeCoverageTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateProjectInputRequestTypeDef = TypedDict(
+    "_RequiredCreateProjectInputRequestTypeDef",
+    {
+        "name": str,
+        "source": "ProjectSourceTypeDef",
+        "artifacts": "ProjectArtifactsTypeDef",
+        "environment": "ProjectEnvironmentTypeDef",
+        "serviceRole": str,
+    },
+)
+_OptionalCreateProjectInputRequestTypeDef = TypedDict(
+    "_OptionalCreateProjectInputRequestTypeDef",
+    {
+        "description": str,
+        "secondarySources": List["ProjectSourceTypeDef"],
+        "sourceVersion": str,
+        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "secondaryArtifacts": List["ProjectArtifactsTypeDef"],
+        "cache": "ProjectCacheTypeDef",
+        "timeoutInMinutes": int,
+        "queuedTimeoutInMinutes": int,
+        "encryptionKey": str,
+        "tags": List["TagTypeDef"],
+        "vpcConfig": "VpcConfigTypeDef",
+        "badgeEnabled": bool,
+        "logsConfig": "LogsConfigTypeDef",
+        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
+        "concurrentBuildLimit": int,
+    },
+    total=False,
+)
+
+
+class CreateProjectInputRequestTypeDef(
+    _RequiredCreateProjectInputRequestTypeDef, _OptionalCreateProjectInputRequestTypeDef
+):
+    pass
+
+
 CreateProjectOutputTypeDef = TypedDict(
     "CreateProjectOutputTypeDef",
     {
@@ -437,6 +568,29 @@ CreateProjectOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateReportGroupInputRequestTypeDef = TypedDict(
+    "_RequiredCreateReportGroupInputRequestTypeDef",
+    {
+        "name": str,
+        "type": ReportTypeType,
+        "exportConfig": "ReportExportConfigTypeDef",
+    },
+)
+_OptionalCreateReportGroupInputRequestTypeDef = TypedDict(
+    "_OptionalCreateReportGroupInputRequestTypeDef",
+    {
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateReportGroupInputRequestTypeDef(
+    _RequiredCreateReportGroupInputRequestTypeDef, _OptionalCreateReportGroupInputRequestTypeDef
+):
+    pass
+
+
 CreateReportGroupOutputTypeDef = TypedDict(
     "CreateReportGroupOutputTypeDef",
     {
@@ -445,6 +599,29 @@ CreateReportGroupOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateWebhookInputRequestTypeDef = TypedDict(
+    "_RequiredCreateWebhookInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+_OptionalCreateWebhookInputRequestTypeDef = TypedDict(
+    "_OptionalCreateWebhookInputRequestTypeDef",
+    {
+        "branchFilter": str,
+        "filterGroups": List[List["WebhookFilterTypeDef"]],
+        "buildType": WebhookBuildTypeType,
+    },
+    total=False,
+)
+
+
+class CreateWebhookInputRequestTypeDef(
+    _RequiredCreateWebhookInputRequestTypeDef, _OptionalCreateWebhookInputRequestTypeDef
+):
+    pass
+
+
 CreateWebhookOutputTypeDef = TypedDict(
     "CreateWebhookOutputTypeDef",
     {
@@ -462,6 +639,13 @@ DebugSessionTypeDef = TypedDict(
     total=False,
 )
 
+DeleteBuildBatchInputRequestTypeDef = TypedDict(
+    "DeleteBuildBatchInputRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
 DeleteBuildBatchOutputTypeDef = TypedDict(
     "DeleteBuildBatchOutputTypeDef",
     {
@@ -472,6 +656,55 @@ DeleteBuildBatchOutputTypeDef = TypedDict(
     },
 )
 
+DeleteProjectInputRequestTypeDef = TypedDict(
+    "DeleteProjectInputRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+
+_RequiredDeleteReportGroupInputRequestTypeDef = TypedDict(
+    "_RequiredDeleteReportGroupInputRequestTypeDef",
+    {
+        "arn": str,
+    },
+)
+_OptionalDeleteReportGroupInputRequestTypeDef = TypedDict(
+    "_OptionalDeleteReportGroupInputRequestTypeDef",
+    {
+        "deleteReports": bool,
+    },
+    total=False,
+)
+
+
+class DeleteReportGroupInputRequestTypeDef(
+    _RequiredDeleteReportGroupInputRequestTypeDef, _OptionalDeleteReportGroupInputRequestTypeDef
+):
+    pass
+
+
+DeleteReportInputRequestTypeDef = TypedDict(
+    "DeleteReportInputRequestTypeDef",
+    {
+        "arn": str,
+    },
+)
+
+DeleteResourcePolicyInputRequestTypeDef = TypedDict(
+    "DeleteResourcePolicyInputRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
+DeleteSourceCredentialsInputRequestTypeDef = TypedDict(
+    "DeleteSourceCredentialsInputRequestTypeDef",
+    {
+        "arn": str,
+    },
+)
+
 DeleteSourceCredentialsOutputTypeDef = TypedDict(
     "DeleteSourceCredentialsOutputTypeDef",
     {
@@ -480,6 +713,40 @@ DeleteSourceCredentialsOutputTypeDef = TypedDict(
     },
 )
 
+DeleteWebhookInputRequestTypeDef = TypedDict(
+    "DeleteWebhookInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+
+_RequiredDescribeCodeCoveragesInputRequestTypeDef = TypedDict(
+    "_RequiredDescribeCodeCoveragesInputRequestTypeDef",
+    {
+        "reportArn": str,
+    },
+)
+_OptionalDescribeCodeCoveragesInputRequestTypeDef = TypedDict(
+    "_OptionalDescribeCodeCoveragesInputRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+        "sortOrder": SortOrderTypeType,
+        "sortBy": ReportCodeCoverageSortByTypeType,
+        "minLineCoveragePercentage": float,
+        "maxLineCoveragePercentage": float,
+    },
+    total=False,
+)
+
+
+class DescribeCodeCoveragesInputRequestTypeDef(
+    _RequiredDescribeCodeCoveragesInputRequestTypeDef,
+    _OptionalDescribeCodeCoveragesInputRequestTypeDef,
+):
+    pass
+
+
 DescribeCodeCoveragesOutputTypeDef = TypedDict(
     "DescribeCodeCoveragesOutputTypeDef",
     {
@@ -489,6 +756,29 @@ DescribeCodeCoveragesOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeTestCasesInputRequestTypeDef = TypedDict(
+    "_RequiredDescribeTestCasesInputRequestTypeDef",
+    {
+        "reportArn": str,
+    },
+)
+_OptionalDescribeTestCasesInputRequestTypeDef = TypedDict(
+    "_OptionalDescribeTestCasesInputRequestTypeDef",
+    {
+        "nextToken": str,
+        "maxResults": int,
+        "filter": "TestCaseFilterTypeDef",
+    },
+    total=False,
+)
+
+
+class DescribeTestCasesInputRequestTypeDef(
+    _RequiredDescribeTestCasesInputRequestTypeDef, _OptionalDescribeTestCasesInputRequestTypeDef
+):
+    pass
+
+
 DescribeTestCasesOutputTypeDef = TypedDict(
     "DescribeTestCasesOutputTypeDef",
     {
@@ -557,6 +847,28 @@ ExportedEnvironmentVariableTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredGetReportGroupTrendInputRequestTypeDef = TypedDict(
+    "_RequiredGetReportGroupTrendInputRequestTypeDef",
+    {
+        "reportGroupArn": str,
+        "trendField": ReportGroupTrendFieldTypeType,
+    },
+)
+_OptionalGetReportGroupTrendInputRequestTypeDef = TypedDict(
+    "_OptionalGetReportGroupTrendInputRequestTypeDef",
+    {
+        "numOfReports": int,
+    },
+    total=False,
+)
+
+
+class GetReportGroupTrendInputRequestTypeDef(
+    _RequiredGetReportGroupTrendInputRequestTypeDef, _OptionalGetReportGroupTrendInputRequestTypeDef
+):
+    pass
+
+
 GetReportGroupTrendOutputTypeDef = TypedDict(
     "GetReportGroupTrendOutputTypeDef",
     {
@@ -566,6 +878,13 @@ GetReportGroupTrendOutputTypeDef = TypedDict(
     },
 )
 
+GetResourcePolicyInputRequestTypeDef = TypedDict(
+    "GetResourcePolicyInputRequestTypeDef",
+    {
+        "resourceArn": str,
+    },
+)
+
 GetResourcePolicyOutputTypeDef = TypedDict(
     "GetResourcePolicyOutputTypeDef",
     {
@@ -581,6 +900,31 @@ GitSubmodulesConfigTypeDef = TypedDict(
     },
 )
 
+_RequiredImportSourceCredentialsInputRequestTypeDef = TypedDict(
+    "_RequiredImportSourceCredentialsInputRequestTypeDef",
+    {
+        "token": str,
+        "serverType": ServerTypeType,
+        "authType": AuthTypeType,
+    },
+)
+_OptionalImportSourceCredentialsInputRequestTypeDef = TypedDict(
+    "_OptionalImportSourceCredentialsInputRequestTypeDef",
+    {
+        "username": str,
+        "shouldOverwrite": bool,
+    },
+    total=False,
+)
+
+
+class ImportSourceCredentialsInputRequestTypeDef(
+    _RequiredImportSourceCredentialsInputRequestTypeDef,
+    _OptionalImportSourceCredentialsInputRequestTypeDef,
+):
+    pass
+
+
 ImportSourceCredentialsOutputTypeDef = TypedDict(
     "ImportSourceCredentialsOutputTypeDef",
     {
@@ -589,6 +933,25 @@ ImportSourceCredentialsOutputTypeDef = TypedDict(
     },
 )
 
+InvalidateProjectCacheInputRequestTypeDef = TypedDict(
+    "InvalidateProjectCacheInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+
+ListBuildBatchesForProjectInputRequestTypeDef = TypedDict(
+    "ListBuildBatchesForProjectInputRequestTypeDef",
+    {
+        "projectName": str,
+        "filter": "BuildBatchFilterTypeDef",
+        "maxResults": int,
+        "sortOrder": SortOrderTypeType,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 ListBuildBatchesForProjectOutputTypeDef = TypedDict(
     "ListBuildBatchesForProjectOutputTypeDef",
     {
@@ -598,6 +961,17 @@ ListBuildBatchesForProjectOutputTypeDef = TypedDict(
     },
 )
 
+ListBuildBatchesInputRequestTypeDef = TypedDict(
+    "ListBuildBatchesInputRequestTypeDef",
+    {
+        "filter": "BuildBatchFilterTypeDef",
+        "maxResults": int,
+        "sortOrder": SortOrderTypeType,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 ListBuildBatchesOutputTypeDef = TypedDict(
     "ListBuildBatchesOutputTypeDef",
     {
@@ -607,6 +981,29 @@ ListBuildBatchesOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListBuildsForProjectInputRequestTypeDef = TypedDict(
+    "_RequiredListBuildsForProjectInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+_OptionalListBuildsForProjectInputRequestTypeDef = TypedDict(
+    "_OptionalListBuildsForProjectInputRequestTypeDef",
+    {
+        "sortOrder": SortOrderTypeType,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListBuildsForProjectInputRequestTypeDef(
+    _RequiredListBuildsForProjectInputRequestTypeDef,
+    _OptionalListBuildsForProjectInputRequestTypeDef,
+):
+    pass
+
+
 ListBuildsForProjectOutputTypeDef = TypedDict(
     "ListBuildsForProjectOutputTypeDef",
     {
@@ -616,6 +1013,15 @@ ListBuildsForProjectOutputTypeDef = TypedDict(
     },
 )
 
+ListBuildsInputRequestTypeDef = TypedDict(
+    "ListBuildsInputRequestTypeDef",
+    {
+        "sortOrder": SortOrderTypeType,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 ListBuildsOutputTypeDef = TypedDict(
     "ListBuildsOutputTypeDef",
     {
@@ -633,6 +1039,16 @@ ListCuratedEnvironmentImagesOutputTypeDef = TypedDict(
     },
 )
 
+ListProjectsInputRequestTypeDef = TypedDict(
+    "ListProjectsInputRequestTypeDef",
+    {
+        "sortBy": ProjectSortByTypeType,
+        "sortOrder": SortOrderTypeType,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 ListProjectsOutputTypeDef = TypedDict(
     "ListProjectsOutputTypeDef",
     {
@@ -642,6 +1058,17 @@ ListProjectsOutputTypeDef = TypedDict(
     },
 )
 
+ListReportGroupsInputRequestTypeDef = TypedDict(
+    "ListReportGroupsInputRequestTypeDef",
+    {
+        "sortOrder": SortOrderTypeType,
+        "sortBy": ReportGroupSortByTypeType,
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
 ListReportGroupsOutputTypeDef = TypedDict(
     "ListReportGroupsOutputTypeDef",
     {
@@ -651,6 +1078,31 @@ ListReportGroupsOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListReportsForReportGroupInputRequestTypeDef = TypedDict(
+    "_RequiredListReportsForReportGroupInputRequestTypeDef",
+    {
+        "reportGroupArn": str,
+    },
+)
+_OptionalListReportsForReportGroupInputRequestTypeDef = TypedDict(
+    "_OptionalListReportsForReportGroupInputRequestTypeDef",
+    {
+        "nextToken": str,
+        "sortOrder": SortOrderTypeType,
+        "maxResults": int,
+        "filter": "ReportFilterTypeDef",
+    },
+    total=False,
+)
+
+
+class ListReportsForReportGroupInputRequestTypeDef(
+    _RequiredListReportsForReportGroupInputRequestTypeDef,
+    _OptionalListReportsForReportGroupInputRequestTypeDef,
+):
+    pass
+
+
 ListReportsForReportGroupOutputTypeDef = TypedDict(
     "ListReportsForReportGroupOutputTypeDef",
     {
@@ -660,6 +1112,17 @@ ListReportsForReportGroupOutputTypeDef = TypedDict(
     },
 )
 
+ListReportsInputRequestTypeDef = TypedDict(
+    "ListReportsInputRequestTypeDef",
+    {
+        "sortOrder": SortOrderTypeType,
+        "nextToken": str,
+        "maxResults": int,
+        "filter": "ReportFilterTypeDef",
+    },
+    total=False,
+)
+
 ListReportsOutputTypeDef = TypedDict(
     "ListReportsOutputTypeDef",
     {
@@ -669,6 +1132,17 @@ ListReportsOutputTypeDef = TypedDict(
     },
 )
 
+ListSharedProjectsInputRequestTypeDef = TypedDict(
+    "ListSharedProjectsInputRequestTypeDef",
+    {
+        "sortBy": SharedResourceSortByTypeType,
+        "sortOrder": SortOrderTypeType,
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
 ListSharedProjectsOutputTypeDef = TypedDict(
     "ListSharedProjectsOutputTypeDef",
     {
@@ -678,6 +1152,17 @@ ListSharedProjectsOutputTypeDef = TypedDict(
     },
 )
 
+ListSharedReportGroupsInputRequestTypeDef = TypedDict(
+    "ListSharedReportGroupsInputRequestTypeDef",
+    {
+        "sortOrder": SortOrderTypeType,
+        "sortBy": SharedResourceSortByTypeType,
+        "nextToken": str,
+        "maxResults": int,
+    },
+    total=False,
+)
+
 ListSharedReportGroupsOutputTypeDef = TypedDict(
     "ListSharedReportGroupsOutputTypeDef",
     {
@@ -919,6 +1404,14 @@ ProjectTypeDef = TypedDict(
     total=False,
 )
 
+PutResourcePolicyInputRequestTypeDef = TypedDict(
+    "PutResourcePolicyInputRequestTypeDef",
+    {
+        "policy": str,
+        "resourceArn": str,
+    },
+)
+
 PutResourcePolicyOutputTypeDef = TypedDict(
     "PutResourcePolicyOutputTypeDef",
     {
@@ -1026,6 +1519,16 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+RetryBuildBatchInputRequestTypeDef = TypedDict(
+    "RetryBuildBatchInputRequestTypeDef",
+    {
+        "id": str,
+        "idempotencyToken": str,
+        "retryType": RetryBuildBatchTypeType,
+    },
+    total=False,
+)
+
 RetryBuildBatchOutputTypeDef = TypedDict(
     "RetryBuildBatchOutputTypeDef",
     {
@@ -1034,6 +1537,15 @@ RetryBuildBatchOutputTypeDef = TypedDict(
     },
 )
 
+RetryBuildInputRequestTypeDef = TypedDict(
+    "RetryBuildInputRequestTypeDef",
+    {
+        "id": str,
+        "idempotencyToken": str,
+    },
+    total=False,
+)
+
 RetryBuildOutputTypeDef = TypedDict(
     "RetryBuildOutputTypeDef",
     {
@@ -1104,6 +1616,56 @@ SourceCredentialsInfoTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredStartBuildBatchInputRequestTypeDef = TypedDict(
+    "_RequiredStartBuildBatchInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+_OptionalStartBuildBatchInputRequestTypeDef = TypedDict(
+    "_OptionalStartBuildBatchInputRequestTypeDef",
+    {
+        "secondarySourcesOverride": List["ProjectSourceTypeDef"],
+        "secondarySourcesVersionOverride": List["ProjectSourceVersionTypeDef"],
+        "sourceVersion": str,
+        "artifactsOverride": "ProjectArtifactsTypeDef",
+        "secondaryArtifactsOverride": List["ProjectArtifactsTypeDef"],
+        "environmentVariablesOverride": List["EnvironmentVariableTypeDef"],
+        "sourceTypeOverride": SourceTypeType,
+        "sourceLocationOverride": str,
+        "sourceAuthOverride": "SourceAuthTypeDef",
+        "gitCloneDepthOverride": int,
+        "gitSubmodulesConfigOverride": "GitSubmodulesConfigTypeDef",
+        "buildspecOverride": str,
+        "insecureSslOverride": bool,
+        "reportBuildBatchStatusOverride": bool,
+        "environmentTypeOverride": EnvironmentTypeType,
+        "imageOverride": str,
+        "computeTypeOverride": ComputeTypeType,
+        "certificateOverride": str,
+        "cacheOverride": "ProjectCacheTypeDef",
+        "serviceRoleOverride": str,
+        "privilegedModeOverride": bool,
+        "buildTimeoutInMinutesOverride": int,
+        "queuedTimeoutInMinutesOverride": int,
+        "encryptionKeyOverride": str,
+        "idempotencyToken": str,
+        "logsConfigOverride": "LogsConfigTypeDef",
+        "registryCredentialOverride": "RegistryCredentialTypeDef",
+        "imagePullCredentialsTypeOverride": ImagePullCredentialsTypeType,
+        "buildBatchConfigOverride": "ProjectBuildBatchConfigTypeDef",
+        "debugSessionEnabled": bool,
+    },
+    total=False,
+)
+
+
+class StartBuildBatchInputRequestTypeDef(
+    _RequiredStartBuildBatchInputRequestTypeDef, _OptionalStartBuildBatchInputRequestTypeDef
+):
+    pass
+
+
 StartBuildBatchOutputTypeDef = TypedDict(
     "StartBuildBatchOutputTypeDef",
     {
@@ -1112,6 +1674,56 @@ StartBuildBatchOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredStartBuildInputRequestTypeDef = TypedDict(
+    "_RequiredStartBuildInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+_OptionalStartBuildInputRequestTypeDef = TypedDict(
+    "_OptionalStartBuildInputRequestTypeDef",
+    {
+        "secondarySourcesOverride": List["ProjectSourceTypeDef"],
+        "secondarySourcesVersionOverride": List["ProjectSourceVersionTypeDef"],
+        "sourceVersion": str,
+        "artifactsOverride": "ProjectArtifactsTypeDef",
+        "secondaryArtifactsOverride": List["ProjectArtifactsTypeDef"],
+        "environmentVariablesOverride": List["EnvironmentVariableTypeDef"],
+        "sourceTypeOverride": SourceTypeType,
+        "sourceLocationOverride": str,
+        "sourceAuthOverride": "SourceAuthTypeDef",
+        "gitCloneDepthOverride": int,
+        "gitSubmodulesConfigOverride": "GitSubmodulesConfigTypeDef",
+        "buildspecOverride": str,
+        "insecureSslOverride": bool,
+        "reportBuildStatusOverride": bool,
+        "buildStatusConfigOverride": "BuildStatusConfigTypeDef",
+        "environmentTypeOverride": EnvironmentTypeType,
+        "imageOverride": str,
+        "computeTypeOverride": ComputeTypeType,
+        "certificateOverride": str,
+        "cacheOverride": "ProjectCacheTypeDef",
+        "serviceRoleOverride": str,
+        "privilegedModeOverride": bool,
+        "timeoutInMinutesOverride": int,
+        "queuedTimeoutInMinutesOverride": int,
+        "encryptionKeyOverride": str,
+        "idempotencyToken": str,
+        "logsConfigOverride": "LogsConfigTypeDef",
+        "registryCredentialOverride": "RegistryCredentialTypeDef",
+        "imagePullCredentialsTypeOverride": ImagePullCredentialsTypeType,
+        "debugSessionEnabled": bool,
+    },
+    total=False,
+)
+
+
+class StartBuildInputRequestTypeDef(
+    _RequiredStartBuildInputRequestTypeDef, _OptionalStartBuildInputRequestTypeDef
+):
+    pass
+
+
 StartBuildOutputTypeDef = TypedDict(
     "StartBuildOutputTypeDef",
     {
@@ -1120,6 +1732,13 @@ StartBuildOutputTypeDef = TypedDict(
     },
 )
 
+StopBuildBatchInputRequestTypeDef = TypedDict(
+    "StopBuildBatchInputRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
 StopBuildBatchOutputTypeDef = TypedDict(
     "StopBuildBatchOutputTypeDef",
     {
@@ -1128,6 +1747,13 @@ StopBuildBatchOutputTypeDef = TypedDict(
     },
 )
 
+StopBuildInputRequestTypeDef = TypedDict(
+    "StopBuildInputRequestTypeDef",
+    {
+        "id": str,
+    },
+)
+
 StopBuildOutputTypeDef = TypedDict(
     "StopBuildOutputTypeDef",
     {
@@ -1178,6 +1804,46 @@ TestReportSummaryTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateProjectInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateProjectInputRequestTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalUpdateProjectInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateProjectInputRequestTypeDef",
+    {
+        "description": str,
+        "source": "ProjectSourceTypeDef",
+        "secondarySources": List["ProjectSourceTypeDef"],
+        "sourceVersion": str,
+        "secondarySourceVersions": List["ProjectSourceVersionTypeDef"],
+        "artifacts": "ProjectArtifactsTypeDef",
+        "secondaryArtifacts": List["ProjectArtifactsTypeDef"],
+        "cache": "ProjectCacheTypeDef",
+        "environment": "ProjectEnvironmentTypeDef",
+        "serviceRole": str,
+        "timeoutInMinutes": int,
+        "queuedTimeoutInMinutes": int,
+        "encryptionKey": str,
+        "tags": List["TagTypeDef"],
+        "vpcConfig": "VpcConfigTypeDef",
+        "badgeEnabled": bool,
+        "logsConfig": "LogsConfigTypeDef",
+        "fileSystemLocations": List["ProjectFileSystemLocationTypeDef"],
+        "buildBatchConfig": "ProjectBuildBatchConfigTypeDef",
+        "concurrentBuildLimit": int,
+    },
+    total=False,
+)
+
+
+class UpdateProjectInputRequestTypeDef(
+    _RequiredUpdateProjectInputRequestTypeDef, _OptionalUpdateProjectInputRequestTypeDef
+):
+    pass
+
+
 UpdateProjectOutputTypeDef = TypedDict(
     "UpdateProjectOutputTypeDef",
     {
@@ -1186,6 +1852,28 @@ UpdateProjectOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateReportGroupInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateReportGroupInputRequestTypeDef",
+    {
+        "arn": str,
+    },
+)
+_OptionalUpdateReportGroupInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateReportGroupInputRequestTypeDef",
+    {
+        "exportConfig": "ReportExportConfigTypeDef",
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class UpdateReportGroupInputRequestTypeDef(
+    _RequiredUpdateReportGroupInputRequestTypeDef, _OptionalUpdateReportGroupInputRequestTypeDef
+):
+    pass
+
+
 UpdateReportGroupOutputTypeDef = TypedDict(
     "UpdateReportGroupOutputTypeDef",
     {
@@ -1194,6 +1882,30 @@ UpdateReportGroupOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateWebhookInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateWebhookInputRequestTypeDef",
+    {
+        "projectName": str,
+    },
+)
+_OptionalUpdateWebhookInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateWebhookInputRequestTypeDef",
+    {
+        "branchFilter": str,
+        "rotateSecret": bool,
+        "filterGroups": List[List["WebhookFilterTypeDef"]],
+        "buildType": WebhookBuildTypeType,
+    },
+    total=False,
+)
+
+
+class UpdateWebhookInputRequestTypeDef(
+    _RequiredUpdateWebhookInputRequestTypeDef, _OptionalUpdateWebhookInputRequestTypeDef
+):
+    pass
+
+
 UpdateWebhookOutputTypeDef = TypedDict(
     "UpdateWebhookOutputTypeDef",
     {
